require File.dirname(__FILE__) + "/version"
require "fileutils"
require "thor"

module BFCLint
  class Generator < Thor
    map ["-v", "--version"] => :version

    desc "install", "Install Barefoot linting defaults into your project"
    def install
      install_files
    end

    desc "update", "Update Barefoot linting defaults"
    def update
      remove_files
      install_files
    end

    private

    def install_files
      FileUtils.mkdir("lintfiles")
      all_lint_files.each do |file|
        puts "Installing #{file}..."
        file_parts = file.split("/")
        unless file_parts.last == "README.md"
          file_name = '.' + file_parts.last
        else
          file_name = file_parts.last
        end
        FileUtils.cp(file, "lintfiles/#{file_name}")
        unless file_name == "README.md"
          FileUtils.ln_s("lintfiles/#{file_name}", file_name)
        end
      end
    end

    def remove_files
      all_lint_files.each do |file| 
        puts "Removing #{file}..."
        file_parts = file.split("/")
        unless file_parts.last == "README.md"
          file_name = '.' + file_parts.last
        else
          file_name = file_parts.last
        end
        if file_name == "README.md"
          file_name = "lintfiles/#{file_name}"
        end

        FileUtils.rm_rf(file_name)
      end
      FileUtils.rm_rf("lintfiles/")
    end

    def all_lint_files
      Dir["#{lint_files_directory}/*"]
    end

    def lint_files_directory
      File.join(top_level_directory, "linter_configurations")
    end

    def top_level_directory
      File.dirname(File.dirname(File.dirname(__FILE__)))
    end
  end
end
